# This is for backwards compatibility and is DEPRECATED
module LibXML
  module XML
    class Tree # :nodoc:
      ELEMENT_NODE = Node::ELEMENT_NODE
      ATTRIBUTE_NODE = Node::ATTRIBUTE_NODE
      TEXT_NODE = Node::TEXT_NODE
      CDATA_SECTION_NODE = Node::CDATA_SECTION_NODE
      ENTITY_REF_NODE = Node::ENTITY_REF_NODE
      ENTITY_NODE = Node::ENTITY_NODE
      PI_NODE = Node::PI_NODE
      COMMENT_NODE = Node::COMMENT_NODE
      DOCUMENT_NODE = Node::DOCUMENT_NODE
      DOCUMENT_TYPE_NODE = Node::DOCUMENT_TYPE_NODE
      DOCUMENT_FRAG_NODE = Node::DOCUMENT_FRAG_NODE
      NOTATION_NODE = Node::NOTATION_NODE
      HTML_DOCUMENT_NODE = Node::HTML_DOCUMENT_NODE
      DTD_NODE = Node::DTD_NODE
      ELEMENT_DECL = Node::ELEMENT_DECL
      ATTRIBUTE_DECL = Node::ATTRIBUTE_DECL
      ENTITY_DECL = Node::ENTITY_DECL
      NAMESPACE_DECL = Node::NAMESPACE_DECL
      XINCLUDE_START = Node::XINCLUDE_START
      XINCLUDE_END = Node::XINCLUDE_END
      DOCB_DOCUMENT_NODE = Node::DOCB_DOCUMENT_NODE
    end  
  end
end